==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/gbinfo.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         if($settings['spam']==1)
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['smilies']==1)
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['bbcodes']==1)
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['zensur']!="")
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['inactive']."</b></font></div>";
                 }
?>
<div style="padding:7px">
<center>
	<div style="border:none">
         <?php
         	echo $info;
         ?>
         </div>
</center>
</div>

==> mgb-0.5.4.5-de.zip: mgb-0.5.4.5-de/gbinfo.php <==
<?php
	/*
	MGB 0.5.4.5
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         if($settings['spam'] == 1)
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['spamprotection'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['smilies'] == 1)
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['smilies'].": <b>".$lang['inactive']."</b></font></div>";
                 }
	if($settings['bbcodes'] == 1)
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['bbcode'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['zensur'] != "")
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['censorship'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['captcha'] == 1)
                 {
                 $info.="<div><font>".$lang['captcha'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['captcha'].": <b>".$lang['inactive']."</b></font></div>";
                 }
         if($settings['ipsperre'] == 1)
                 {
                 $info.="<div><font>".$lang['ipblocker'].": <b>".$lang['active']."</b></font></div>";
                 }
         else
                 {
                 $info.="<div><font>".$lang['ipblocker'].": <b>".$lang['inactive']."</b></font></div>";
                 }
?>
<div style="padding:7px">
<center>
<div style="border:none">
<?php
	echo $info;
?>
</div>
</center>
</div>
